==> unicore-uvos-server-1.5.1-0.src.tar.gz: src/main/java/pl/edu/icm/unicore/uvos/server/WSApplicationsImpl.java <==
/*
 * Copyright (c) 2007, 2008 ICM Uniwersytet Warszawski All rights reserved.
 * See LICENCE file for licencing information.
 *
 * Created on Aug 7, 2007
 * Author: K. Benedyczak <golbi@mat.umk.pl>
 */

package pl.edu.icm.unicore.uvos.server;

import java.util.List;

import javax.jws.WebService;

import org.apache.log4j.Logger;
import org.apache.xmlbeans.XmlException;

import pl.edu.icm.unicore.uvos.api.ApplicationActions;
import pl.edu.icm.unicore.uvos.api.VOApplication;
import pl.edu.icm.unicore.uvos.api.exceptions.InternalException;
import pl.edu.icm.unicore.uvos.api.exceptions.UVOSException;
import pl.edu.icm.unicore.uvos.api.exceptions.VOApplicationException;
import pl.edu.icm.unicore.uvos.engine.api.VOApplicationInterface;
import pl.edu.icm.unicore.uvos.server.idresolver.Authenticator;
import pl.edu.icm.unicore.uvos.wsapi.xmlbeans.UVOSFault;
import pl.edu.icm.unicore.uvos.wsapi.xmlbeans.WSApplicationsInterface;
import pl.edu.icm.unicore.uvos.wsapi.xmlbeans.XMLBeansMapper;
import xmlbeans.pl.edu.icm.uvos.internal.app.ProcessVOApplicationDocument;
import xmlbeans.pl.edu.icm.uvos.internal.app.ProcessVOApplicationType;
import xmlbeans.pl.edu.icm.uvos.internal.app.VOApplicationDocument;
import xmlbeans.pl.edu.icm.uvos.internal.app.VOApplicationFormDocument;
import xmlbeans.pl.edu.icm.uvos.internal.app.VOApplicationFormListDocument;
import xmlbeans.pl.edu.icm.uvos.internal.app.VOApplicationListDocument;

/**
 * @author K. Benedyczak
 */
@WebService(endpointInterface="pl.edu.icm.unicore.uvos.wsapi.WSApplicationsInterface")
public class WSApplicationsImpl implements WSApplicationsInterface
{
	private static final Logger log = Logger.getLogger(WSApplicationsImpl.class); 
	private VOApplicationInterface voApps;
	private Authenticator authenticator;

	public WSApplicationsImpl(VOApplicationInterface voApps, Authenticator authenticator) throws InternalException
	{
		this.voApps = voApps;
		this.authenticator = authenticator;
	}

	public VOApplicationFormListDocument getApplicationForms() throws UVOSFault
	{
		try
		{
			log.debug("getApplicationForms invoked");
			authenticator.authenticate();
			return XMLBeansMapper.map2XMLVOApplicationFormList(
					voApps.getApplicationForms());
		} catch (UVOSException e)
		{
			log.info("Error invoking getApplicationForms: " + e);
			throw new UVOSFault(e);
		} catch (XmlException e)
		{
			log.info("Error invoking getApplicationForms: Unparseable constraints");
			throw new UVOSFault(new VOApplicationException(
					"Unparseable constraints"));
		}
	}

	public void removeApplicationForm(int id) throws UVOSFault
	{
		try
		{
			log.debug("removeApplicationForm invoked");
			authenticator.authenticate();
			voApps.removeApplicationForm(id);
			log.debug("Removed application form with id " + id);
		} catch (UVOSException e)
		{
			log.info("Error invoking removeApplicationForm: " + e);
			throw new UVOSFault(e);
		}
	}

	public void updateApplicationForm(VOApplicationFormDocument applicationDef, 
			boolean update) throws UVOSFault
	{
		try
		{
			log.debug("updateApplicationForm invoked");
			authenticator.authenticate();
			voApps.updateApplicationForm(XMLBeansMapper.map2APIVOApplicationForm
					(applicationDef), update);
			if (log.isDebugEnabled())
				log.debug((update ? "Updated" : "Created") + " application form " 
					+ applicationDef.xmlText());
		} catch (UVOSException e)
		{
			log.info("Error invoking updateApplicationForm: " + e);
			throw new UVOSFault(e);
		}
	}

	public void submitApplication(VOApplicationDocument application) throws UVOSFault
	{
		try
		{
			log.debug("submitApplication invoked");
			authenticator.authenticate();
			voApps.submitApplication(XMLBeansMapper.map2APIVOApplication(
					application));
			if (log.isDebugEnabled())
				log.debug("A new application was submitted: " + 
					application.xmlText());
		} catch (UVOSException e)
		{
			log.info("Error invoking submitApplication: " + e);
			throw new UVOSFault(e);
		}
	}

	public VOApplicationListDocument getApplications(Integer formId, String status) 
		throws UVOSFault
	{
		try
		{
			log.debug("getApplications invoked");
			authenticator.authenticate();
			List<VOApplication> ret = voApps.getApplications(formId, status);
			return XMLBeansMapper.map2XMLVOApplicationList(ret);
		} catch (UVOSException e)
		{
			log.info("Error invoking getApplications: " + e);
			throw new UVOSFault(e);
		} catch (XmlException e)
		{
			log.info("Error invoking getApplications: Unparseable request details");
			throw new UVOSFault(new VOApplicationException(
					"Unparseable request details"));
		}
	}

	public void processApplication(ProcessVOApplicationDocument orderDoc) 
		throws UVOSFault
	{
		ProcessVOApplicationType order = orderDoc.getProcessVOApplication();
		try
		{
			log.debug("processApplication invoked");
			authenticator.authenticate();
			voApps.processApplication(order.getApplicationId(), 
				ApplicationActions.valueOf(order.getAction().toString()), 
				order.getNotes(),
				order.getSendConfirmation(),
				(order.getUpdatedApplication() == null) ? null :  
				XMLBeansMapper.map2APIVOApplication(order.getUpdatedApplication()));
			if (log.isDebugEnabled())
				log.debug("Processed application " + order.getApplicationId() 
					+ ": action is " + order.getAction().toString() + 
					", note is " + order.getNotes());
		} catch (UVOSException e)
		{
			log.info("Error invoking processApplication: " + e);
			throw new UVOSFault(e);
		} catch (IllegalArgumentException e)
		{
			String msg = "Action is invalid: " + 
				order.getAction().toString();
			log.info("Error invoking processApplication: " + msg);
			throw new UVOSFault(new VOApplicationException(msg));
		}
	}

	public void csrProcessedNotification(String csr, boolean accepted, 
			String certificate, boolean sendNotification) throws UVOSFault
	{
		try
		{
			log.debug("csrProcessedNotification invoked");
			authenticator.authenticate();
			voApps.csrProcessedNotification(csr, accepted, certificate, 
					sendNotification);
			if (log.isDebugEnabled())
				log.debug("Proccessed a CSR application. CSR was " +
					(accepted ? "accepted" : "rejected"));
			log.trace("Certificate issued to CSR is\n" + certificate);
		} catch (UVOSException e)
		{
			log.info("Error invoking csrProcessedNotification: " + e);
			throw new UVOSFault(e);
		}
	}
}

==> unicore-uvos-server-1.6.0-0.src.tar.gz: src/main/java/pl/edu/icm/unicore/uvos/server/WSApplicationsImpl.java <==
/*
 * Copyright (c) 2007, 2008 ICM Uniwersytet Warszawski All rights reserved.
 * See LICENCE file for licencing information.
 *
 * Created on Aug 7, 2007
 * Author: K. Benedyczak <golbi@mat.umk.pl>
 */

package pl.edu.icm.unicore.uvos.server;

import java.util.List;

import javax.jws.WebService;

import org.apache.log4j.Logger;
import org.apache.xmlbeans.XmlException;

import eu.unicore.util.Log;

import pl.edu.icm.unicore.uvos.api.ApplicationActions;
import pl.edu.icm.unicore.uvos.api.VOApplication;
import pl.edu.icm.unicore.uvos.api.exceptions.InternalException;
import pl.edu.icm.unicore.uvos.api.exceptions.UVOSException;
import pl.edu.icm.unicore.uvos.api.exceptions.VOApplicationException;
import pl.edu.icm.unicore.uvos.engine.api.VOApplicationInterface;
import pl.edu.icm.unicore.uvos.server.idresolver.Authenticator;
import pl.edu.icm.unicore.uvos.util.UVOSServerProperties;
import pl.edu.icm.unicore.uvos.wsapi.xmlbeans.UVOSFault;
import pl.edu.icm.unicore.uvos.wsapi.xmlbeans.WSApplicationsInterface;
import pl.edu.icm.unicore.uvos.wsapi.xmlbeans.XMLBeansMapper;
import xmlbeans.pl.edu.icm.uvos.internal.app.ProcessVOApplicationDocument;
import xmlbeans.pl.edu.icm.uvos.internal.app.ProcessVOApplicationType;
import xmlbeans.pl.edu.icm.uvos.internal.app.VOApplicationDocument;
import xmlbeans.pl.edu.icm.uvos.internal.app.VOApplicationFormDocument;
import xmlbeans.pl.edu.icm.uvos.internal.app.VOApplicationFormListDocument;
import xmlbeans.pl.edu.icm.uvos.internal.app.VOApplicationListDocument;

/**
 * @author K. Benedyczak
 */
@WebService(endpointInterface="pl.edu.icm.unicore.uvos.wsapi.WSApplicationsInterface")
public class WSApplicationsImpl implements WSApplicationsInterface
{
	private static final Logger log = Log.getLogger(UVOSServerProperties.LOG_PFX, WSApplicationsImpl.class); 
	private VOApplicationInterface voApps;
	private Authenticator authenticator;

	public WSApplicationsImpl(VOApplicationInterface voApps, Authenticator authenticator) throws InternalException
	{
		this.voApps = voApps;
		this.authenticator = authenticator;
	}

	public VOApplicationFormListDocument getApplicationForms() throws UVOSFault
	{
		try
		{
			log.debug("getApplicationForms invoked");
			authenticator.authenticate();
			return XMLBeansMapper.map2XMLVOApplicationFormList(
					voApps.getApplicationForms());
		} catch (UVOSException e)
		{
			log.info("Error invoking getApplicationForms: " + e);
			throw new UVOSFault(e);
		} catch (XmlException e)
		{
			log.info("Error invoking getApplicationForms: Unparseable constraints");
			throw new UVOSFault(new VOApplicationException(
					"Unparseable constraints"));
		}
	}

	public void removeApplicationForm(int id) throws UVOSFault
	{
		try
		{
			log.debug("removeApplicationForm invoked");
			authenticator.authenticate();
			voApps.removeApplicationForm(id);
			log.debug("Removed application form with id " + id);
		} catch (UVOSException e)
		{
			log.info("Error invoking removeApplicationForm: " + e);
			throw new UVOSFault(e);
		}
	}

	public void updateApplicationForm(VOApplicationFormDocument applicationDef, 
			boolean update) throws UVOSFault
	{
		try
		{
			log.debug("updateApplicationForm invoked");
			authenticator.authenticate();
			voApps.updateApplicationForm(XMLBeansMapper.map2APIVOApplicationForm
					(applicationDef), update);
			if (log.isDebugEnabled())
				log.debug((update ? "Updated" : "Created") + " application form " 
					+ applicationDef.xmlText());
		} catch (UVOSException e)
		{
			log.info("Error invoking updateApplicationForm: " + e);
			throw new UVOSFault(e);
		}
	}

	public void submitApplication(VOApplicationDocument application) throws UVOSFault
	{
		try
		{
			log.debug("submitApplication invoked");
			authenticator.authenticate();
			voApps.submitApplication(XMLBeansMapper.map2APIVOApplication(
					application));
			if (log.isDebugEnabled())
				log.debug("A new application was submitted: " + 
					application.xmlText());
		} catch (UVOSException e)
		{
			log.info("Error invoking submitApplication: " + e);
			throw new UVOSFault(e);
		}
	}

	public VOApplicationListDocument getApplications(Integer formId, String status) 
		throws UVOSFault
	{
		try
		{
			log.debug("getApplications invoked");
			authenticator.authenticate();
			List<VOApplication> ret = voApps.getApplications(formId, status);
			return XMLBeansMapper.map2XMLVOApplicationList(ret);
		} catch (UVOSException e)
		{
			log.info("Error invoking getApplications: " + e);
			throw new UVOSFault(e);
		} catch (XmlException e)
		{
			log.info("Error invoking getApplications: Unparseable request details");
			throw new UVOSFault(new VOApplicationException(
					"Unparseable request details"));
		}
	}

	public void processApplication(ProcessVOApplicationDocument orderDoc) 
		throws UVOSFault
	{
		ProcessVOApplicationType order = orderDoc.getProcessVOApplication();
		try
		{
			log.debug("processApplication invoked");
			authenticator.authenticate();
			voApps.processApplication(order.getApplicationId(), 
				ApplicationActions.valueOf(order.getAction().toString()), 
				order.getNotes(),
				order.getSendConfirmation(),
				(order.getUpdatedApplication() == null) ? null :  
				XMLBeansMapper.map2APIVOApplication(order.getUpdatedApplication()));
			if (log.isDebugEnabled())
				log.debug("Processed application " + order.getApplicationId() 
					+ ": action is " + order.getAction().toString() + 
					", note is " + order.getNotes());
		} catch (UVOSException e)
		{
			log.info("Error invoking processApplication: " + e);
			throw new UVOSFault(e);
		} catch (IllegalArgumentException e)
		{
			String msg = "Action is invalid: " + 
				order.getAction().toString();
			log.info("Error invoking processApplication: " + msg);
			throw new UVOSFault(new VOApplicationException(msg));
		}
	}

	public void csrProcessedNotification(String csr, boolean accepted, 
			String certificate, boolean sendNotification) throws UVOSFault
	{
		try
		{
			log.debug("csrProcessedNotification invoked");
			authenticator.authenticate();
			voApps.csrProcessedNotification(csr, accepted, certificate, 
					sendNotification);
			if (log.isDebugEnabled())
				log.debug("Proccessed a CSR application. CSR was " +
					(accepted ? "accepted" : "rejected"));
			log.trace("Certificate issued to CSR is\n" + certificate);
		} catch (UVOSException e)
		{
			log.info("Error invoking csrProcessedNotification: " + e);
			throw new UVOSFault(e);
		}
	}
}
